@@ -42,7 +42,10 @@ class Entity:
                     headers=self.emmiter.graphql_headers,
                     json=mpc_,
                 )
-                j = r.json()
+                try:
+                    j = r.json()
+                except json.decoder.JSONDecodeError:
+                    raise ValueError(r.text)
                 if "errors" in j:
                     logging.error(f"request url: {r.url}")
                     logging.error(f"request header: {self.emmiter.graphql_headers}")
@@ -75,6 +78,7 @@ class Entity:
             else iglob(file_pattern, recursive=recursive)
         )
         for filepath in files_iter:
+            logging.info(f"processing: {filepath}")
             with open(filepath, "r") as f:
                 j = json.load(f)
                 if isinstance(j, dict):
