@@ -40,7 +40,7 @@ class Dataset(Entity):
         self,
         name: str,
         platform: str = "bigquery",
-        env: str = "DEV",
+        env: str = None,
         description: str = None,
         url: str = None,
         tags: List[str] = None,
@@ -51,7 +51,7 @@ class Dataset(Entity):
         links: dict = None,
     ) -> List[dict]:
         dataset_urn: str = builder.make_dataset_urn(
-            platform=platform, name=name, env=env
+            platform=platform, name=name, env=env or self.emmiter.env
         )
         """Create list of mpc dictionaries for dataset modifications.
         
@@ -151,11 +151,7 @@ class Dataset(Entity):
             ),
         )
 
-    def remove_tag(
-        self,
-        dataset_urn: str,
-        tag: str
-    ) -> None:
+    def remove_tag(self, dataset_urn: str, tag: str) -> None:
         """Remove tag from a dataset
 
         Examples:
